@@ -62,24 +62,6 @@ class HpoExperiment(BaseObject):
     hpo_concurrency : :obj:`int`, optional
         调优期望并行度，即期望同时运行的任务数，实际并行度视后端资源调度情况而定。
         默认为 :obj:`1` 。
-    gpu_num : :obj:`int`, optional
-        向Anylearn后端引擎请求的GPU数量。
-        默认为1。
-
-        .. deprecated:: 0.11.1
-
-            Use :obj:`resources_request` instead
-            to specify QuotaGroup and resource request.
-
-    gpu_mem : :obj:`int`, optional
-        向Anylearn后端引擎请求的显存大小。
-        默认为0。
-
-        .. deprecated:: 0.11.1
-
-            Use :obj:`resources_request` instead
-            to specify QuotaGroup and resource request.
-
     resource_request : :obj:`List[Dict[str, Dict[str, int]]]`, optional
         单次训练所需计算资源的请求。
         如未填，则使用Anylearn后端的:obj:`default`资源组中的默认资源套餐。
@@ -136,8 +118,6 @@ class HpoExperiment(BaseObject):
                  hpo_tuner_name: Optional[str]="TPE",
                  hpo_mode: Optional[str]="maximize",
                  hpo_concurrency: Optional[int]=1,
-                 gpu_num: Optional[int]=-1, # deprecated 0.11.1 - remove soon
-                 gpu_mem: Optional[int]=-1, # deprecated 0.11.1 - remove soon
                  resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                  created_at: Optional[datetime]=utc_plus_8(),
                  hpo_id: Optional[str]=None,
@@ -179,24 +159,6 @@ class HpoExperiment(BaseObject):
         hpo_concurrency : :obj:`int`, optional
             调优期望并行度，即期望同时运行的任务数，实际并行度视后端资源调度情况而定。
             默认为 :obj:`1` 。
-        gpu_num : :obj:`int`, optional
-            向Anylearn后端引擎请求的GPU数量。
-            默认为1。
-
-            .. deprecated:: 0.11.1
-
-                Use :obj:`resources_request` instead
-                to specify QuotaGroup and resource request.
-
-        gpu_mem : :obj:`int`, optional
-            向Anylearn后端引擎请求的显存大小。
-            默认为0。
-
-            .. deprecated:: 0.11.1
-
-                Use :obj:`resources_request` instead
-                to specify QuotaGroup and resource request.
-
         resource_request : :obj:`List[Dict[str, Dict[str, int]]]`, optional
             单次训练所需计算资源的请求。
             如未填，则使用Anylearn后端的:obj:`default`资源组中的默认资源套餐。
@@ -234,8 +196,6 @@ class HpoExperiment(BaseObject):
         self.hpo_tuner_name = hpo_tuner_name
         self.hpo_mode = hpo_mode
         self.hpo_concurrency = hpo_concurrency
-        self.gpu_num = -1 # deprecated 0.11.1 - remove soon
-        self.gpu_mem = -1 # deprecated 0.11.1 - remove soon
         self.resource_request = resource_request
         self.created_at = created_at
         self.hpo_id = hpo_id
