@@ -222,21 +222,25 @@ def _create_train_task(name: str,
                        algorithm: Algorithm,
                        project: Project,
                        hyperparams: dict,
-                       mounts: Optional[Dict[str, Resource]]=None,
+                       mounts: Optional[Union[Dict[str, List[Resource]], Dict[str, Resource]]]=None,
                        algorithm_git_ref: Optional[str]=None,
                        resource_request: Optional[List[Dict[str, Dict[str, int]]]]=None,
                        description: Optional[str]=None):
-    files = [v.id for v in mounts.values()]
-    train_params = dict(
-        {k: f"${v.id}" for k, v in mounts.items()},
-        **hyperparams,
-    )
+    resource_ids = []
+    train_params = hyperparams
+    for k, v in mounts.items():
+        if isinstance(v, list):
+            resource_ids.extend([v_item.id for v_item in v])
+            train_params[k] = [f"${v_item.id}" for v_item in v]
+        else:
+            resource_ids.append(v.id)
+            train_params[k] = f"${v.id}"
     train_task = TrainTask(
         name=name,
         project_id=project.id,
         algorithm_id=algorithm.id,
         algorithm_git_ref=algorithm_git_ref,
-        files=files,
+        files=resource_ids,
         train_params=json.dumps(train_params),
         resource_request=resource_request,
         description=description,
@@ -249,7 +253,6 @@ def _create_train_task(name: str,
 def quick_train(algorithm_id: Optional[str]=None,
                 algorithm_name: Optional[str]=None,
                 algorithm_dir: Optional[Union[str, Path]]=None,
-                algorithm_archive: Optional[str]=None, # deprecated in 0.11.11, remove in 0.12.3
                 algorithm_force_update: bool=False,
                 algorithm_git_ref: Optional[str]=None,
                 dataset_hyperparam_name: str="dataset",
@@ -259,7 +262,7 @@ def quick_train(algorithm_id: Optional[str]=None,
                 model_hyperparam_name: str="model",
                 model_id: Optional[str]=None,
                 pretrain_hyperparam_name: str="pretrain",
-                pretrain_task_id: Optional[str]=None,
+                pretrain_task_id: Optional[Union[List[str], str]]=None,
                 project_id: Optional[str]=None,
                 project_name: Optional[str]=None,
                 entrypoint: Optional[str]=None,
@@ -311,13 +314,6 @@ def quick_train(algorithm_id: Optional[str]=None,
         原有版本仍可追溯。
     algorithm_dir : :obj:`str`, optional
         本地算法目录路径。
-    algorithm_archive : :obj:`str`, optional
-        本地算法压缩包路径。
-
-        .. deprecated:: 0.12.0
-
-            Not supported anymore.
-
     algorithm_git_ref : :obj:`str`, optional
         算法Gitea代码仓库的版本号（可以是commit号、分支名、tag名）。
         使用本地算法时，如未提供此参数，则取本地算法当前分支名。
@@ -346,7 +342,7 @@ def quick_train(algorithm_id: Optional[str]=None,
         需指定长参数名，如 :obj:`--pretrain` ，并省略 :obj:`--` 部分传入。
         预训练结果路径由Anylearn后端引擎管理。
         默认为 :obj:`pretrain` 。
-    pretrain_task_id: :obj:`str`, optional
+    pretrain_task_id: :obj:`List[str] | `:obj:`str`, optional
         在Anylearn进行过的训练的ID，一般为前缀TRAI的32位字符串。
         Anylearn会对指定的训练进行结果抽取并挂载到新一次的训练中。
     project_id : :obj:`str`, optional
@@ -391,11 +387,14 @@ def quick_train(algorithm_id: Optional[str]=None,
     model = Model(id=model_id, load_detail=True) if model_id else None
 
     # Remote pretrain task results
-    pretrain_task = (
-        TrainTask(id=pretrain_task_id, load_detail=True)
-        if pretrain_task_id
-        else None
-    )
+    if pretrain_task_id == None:
+        pretrain_task_id = []
+    elif not isinstance(pretrain_task_id, list):
+        pretrain_task_id = [pretrain_task_id]
+    pretrain_tasks = [
+        TrainTask(id=_id, load_detail=True)
+        for _id in pretrain_task_id 
+    ]
 
     # Algorithm
     try:
@@ -438,8 +437,8 @@ def quick_train(algorithm_id: Optional[str]=None,
         mounts[dataset_hyperparam_name] = dset
     if model and model_hyperparam_name:
         mounts[model_hyperparam_name] = model
-    if pretrain_task and pretrain_hyperparam_name:
-        mounts[pretrain_hyperparam_name] = pretrain_task.get_results_file()
+    if pretrain_tasks and pretrain_hyperparam_name:
+        mounts[pretrain_hyperparam_name] = [t.get_results_file() for t in pretrain_tasks]
 
     # Project
     if project_id or project_name:
@@ -473,7 +472,6 @@ def quick_train(algorithm_id: Optional[str]=None,
                                  dataset_id=dset.id if dset else None,
                                  train_params=train_task.train_params,
                                  algorithm_dir=str(algorithm_dir),
-                                 algorithm_archive=algorithm_archive,
                                  dataset_dir=str(dataset_dir),
                                  dataset_archive=dataset_archive,)
     train_profile.create_in_db()
